/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "bamf-gdbus-generated.h"

#include <string.h>
#ifdef G_OS_UNIX
#  include <gio/gunixfdlist.h>
#endif

#ifdef G_ENABLE_DEBUG
#define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
#define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
#define g_marshal_value_peek_int(v)      g_value_get_int (v)
#define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
#define g_marshal_value_peek_long(v)     g_value_get_long (v)
#define g_marshal_value_peek_ulong(v)    g_value_get_ulong (v)
#define g_marshal_value_peek_int64(v)    g_value_get_int64 (v)
#define g_marshal_value_peek_uint64(v)   g_value_get_uint64 (v)
#define g_marshal_value_peek_enum(v)     g_value_get_enum (v)
#define g_marshal_value_peek_flags(v)    g_value_get_flags (v)
#define g_marshal_value_peek_float(v)    g_value_get_float (v)
#define g_marshal_value_peek_double(v)   g_value_get_double (v)
#define g_marshal_value_peek_string(v)   (char*) g_value_get_string (v)
#define g_marshal_value_peek_param(v)    g_value_get_param (v)
#define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
#define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
#define g_marshal_value_peek_object(v)   g_value_get_object (v)
#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
#else /* !G_ENABLE_DEBUG */
/* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
 *          Do not access GValues directly in your code. Instead, use the
 *          g_value_get_*() functions
 */
#define g_marshal_value_peek_boolean(v)  (v)->data[0].v_int
#define g_marshal_value_peek_char(v)     (v)->data[0].v_int
#define g_marshal_value_peek_uchar(v)    (v)->data[0].v_uint
#define g_marshal_value_peek_int(v)      (v)->data[0].v_int
#define g_marshal_value_peek_uint(v)     (v)->data[0].v_uint
#define g_marshal_value_peek_long(v)     (v)->data[0].v_long
#define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
#define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
#define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
#define g_marshal_value_peek_float(v)    (v)->data[0].v_float
#define g_marshal_value_peek_double(v)   (v)->data[0].v_double
#define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
#define g_marshal_value_peek_param(v)    (v)->data[0].v_pointer
#define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
#define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
#define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
#endif /* !G_ENABLE_DEBUG */

typedef struct
{
  GDBusArgInfo parent_struct;
  gboolean use_gvariant;
} _ExtendedGDBusArgInfo;

typedef struct
{
  GDBusMethodInfo parent_struct;
  const gchar *signal_name;
  gboolean pass_fdlist;
} _ExtendedGDBusMethodInfo;

typedef struct
{
  GDBusSignalInfo parent_struct;
  const gchar *signal_name;
} _ExtendedGDBusSignalInfo;

typedef struct
{
  GDBusPropertyInfo parent_struct;
  const gchar *hyphen_name;
  guint use_gvariant : 1;
  guint emits_changed_signal : 1;
} _ExtendedGDBusPropertyInfo;

typedef struct
{
  GDBusInterfaceInfo parent_struct;
  const gchar *hyphen_name;
} _ExtendedGDBusInterfaceInfo;

typedef struct
{
  const _ExtendedGDBusPropertyInfo *info;
  guint prop_id;
  GValue orig_value; /* the value before the change */
} ChangedProperty;

static void
_changed_property_free (ChangedProperty *data)
{
  g_value_unset (&data->orig_value);
  g_free (data);
}

static gboolean
_g_strv_equal0 (gchar **a, gchar **b)
{
  gboolean ret = FALSE;
  guint n;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  if (g_strv_length (a) != g_strv_length (b))
    goto out;
  for (n = 0; a[n] != NULL; n++)
    if (g_strcmp0 (a[n], b[n]) != 0)
      goto out;
  ret = TRUE;
out:
  return ret;
}

static gboolean
_g_variant_equal0 (GVariant *a, GVariant *b)
{
  gboolean ret = FALSE;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  ret = g_variant_equal (a, b);
out:
  return ret;
}

G_GNUC_UNUSED static gboolean
_g_value_equal (const GValue *a, const GValue *b)
{
  gboolean ret = FALSE;
  g_assert (G_VALUE_TYPE (a) == G_VALUE_TYPE (b));
  switch (G_VALUE_TYPE (a))
    {
      case G_TYPE_BOOLEAN:
        ret = (g_value_get_boolean (a) == g_value_get_boolean (b));
        break;
      case G_TYPE_UCHAR:
        ret = (g_value_get_uchar (a) == g_value_get_uchar (b));
        break;
      case G_TYPE_INT:
        ret = (g_value_get_int (a) == g_value_get_int (b));
        break;
      case G_TYPE_UINT:
        ret = (g_value_get_uint (a) == g_value_get_uint (b));
        break;
      case G_TYPE_INT64:
        ret = (g_value_get_int64 (a) == g_value_get_int64 (b));
        break;
      case G_TYPE_UINT64:
        ret = (g_value_get_uint64 (a) == g_value_get_uint64 (b));
        break;
      case G_TYPE_DOUBLE:
        {
          /* Avoid -Wfloat-equal warnings by doing a direct bit compare */
          gdouble da = g_value_get_double (a);
          gdouble db = g_value_get_double (b);
          ret = memcmp (&da, &db, sizeof (gdouble)) == 0;
        }
        break;
      case G_TYPE_STRING:
        ret = (g_strcmp0 (g_value_get_string (a), g_value_get_string (b)) == 0);
        break;
      case G_TYPE_VARIANT:
        ret = _g_variant_equal0 (g_value_get_variant (a), g_value_get_variant (b));
        break;
      default:
        if (G_VALUE_TYPE (a) == G_TYPE_STRV)
          ret = _g_strv_equal0 (g_value_get_boxed (a), g_value_get_boxed (b));
        else
          g_critical ("_g_value_equal() does not handle type %s", g_type_name (G_VALUE_TYPE (a)));
        break;
    }
  return ret;
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 2);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectStringFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        const gchar *arg_desktop_path,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectStringFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectStringFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_string (param_values + 2),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING_INT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectStringIntFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        const gchar *arg_application,
        gint arg_pid,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectStringIntFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 4);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectStringIntFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_string (param_values + 2),
              g_marshal_value_peek_int (param_values + 3),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_VOID__STRING_STRING (
    GClosure     *closure,
    GValue       *return_value G_GNUC_UNUSED,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef void (*_GDbusCodegenMarshalVoid_StringStringFunc)
       (void *data1,
        const gchar *arg_old_app,
        const gchar *arg_new_app,
        void *data2);
  _GDbusCodegenMarshalVoid_StringStringFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;

  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalVoid_StringStringFunc)
    (marshal_data ? marshal_data : cc->callback);

  callback (data1,
            g_marshal_value_peek_string (param_values + 1),
            g_marshal_value_peek_string (param_values + 2),
            data2);
}

static void
_g_dbus_codegen_marshal_VOID__BOXED_BOXED (
    GClosure     *closure,
    GValue       *return_value G_GNUC_UNUSED,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef void (*_GDbusCodegenMarshalVoid_BoxedBoxedFunc)
       (void *data1,
        const gchar *const *arg_opened_desktop_files,
        const gchar *const *arg_closed_desktop_files,
        void *data2);
  _GDbusCodegenMarshalVoid_BoxedBoxedFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;

  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalVoid_BoxedBoxedFunc)
    (marshal_data ? marshal_data : cc->callback);

  callback (data1,
            g_marshal_value_peek_boxed (param_values + 1),
            g_marshal_value_peek_boxed (param_values + 2),
            data2);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_BOXED (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectBoxedFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        const gchar *const *arg_favorites,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectBoxedFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectBoxedFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_boxed (param_values + 2),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_UINT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectUintFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        guint arg_xid,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectUintFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectUintFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_uint (param_values + 2),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_INT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectIntFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        gint arg_monitor_id,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectIntFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectIntFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_int (param_values + 2),
              data2);

  g_value_set_boolean (return_value, v_return);
}

/* ------------------------------------------------------------------------
 * Code for interface org.ayatana.bamf.control
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:BamfDBusControl
 * @title: BamfDBusControl
 * @short_description: Generated C code for the org.ayatana.bamf.control D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link> D-Bus interface in C.
 */

/* ---- Introspection data for org.ayatana.bamf.control ---- */

static const _ExtendedGDBusMethodInfo __bamf_dbus_control_method_info_quit =
{
  {
    -1,
    (gchar *) "Quit",
    NULL,
    NULL,
    NULL
  },
  "handle-quit",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_control_method_info_insert_desktop_file_IN_ARG_desktop_path =
{
  {
    -1,
    (gchar *) "desktop_path",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_control_method_info_insert_desktop_file_IN_ARG_pointers[] =
{
  &__bamf_dbus_control_method_info_insert_desktop_file_IN_ARG_desktop_path.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_control_method_info_insert_desktop_file =
{
  {
    -1,
    (gchar *) "InsertDesktopFile",
    (GDBusArgInfo **) &__bamf_dbus_control_method_info_insert_desktop_file_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-insert-desktop-file",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_application =
{
  {
    -1,
    (gchar *) "application",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_pid =
{
  {
    -1,
    (gchar *) "pid",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_pointers[] =
{
  &__bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_application.parent_struct,
  &__bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_pid.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_control_method_info_register_application_for_pid =
{
  {
    -1,
    (gchar *) "RegisterApplicationForPid",
    (GDBusArgInfo **) &__bamf_dbus_control_method_info_register_application_for_pid_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-register-application-for-pid",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_control_method_info_create_local_desktop_file_IN_ARG_application =
{
  {
    -1,
    (gchar *) "application",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_control_method_info_create_local_desktop_file_IN_ARG_pointers[] =
{
  &__bamf_dbus_control_method_info_create_local_desktop_file_IN_ARG_application.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_control_method_info_create_local_desktop_file =
{
  {
    -1,
    (gchar *) "CreateLocalDesktopFile",
    (GDBusArgInfo **) &__bamf_dbus_control_method_info_create_local_desktop_file_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-create-local-desktop-file",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_control_method_info_om_nom_nom_desktop_file_IN_ARG_desktop_path =
{
  {
    -1,
    (gchar *) "desktop_path",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_control_method_info_om_nom_nom_desktop_file_IN_ARG_pointers[] =
{
  &__bamf_dbus_control_method_info_om_nom_nom_desktop_file_IN_ARG_desktop_path.parent_struct,
  NULL
};

static const GDBusAnnotationInfo __bamf_dbus_control_method_om_nom_nom_desktop_file_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.Deprecated",
  (gchar *) "true",
  NULL
};

static const GDBusAnnotationInfo * const __bamf_dbus_control_method_om_nom_nom_desktop_file_annotation_info_pointers[] =
{
  &__bamf_dbus_control_method_om_nom_nom_desktop_file_annotation_info_0,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_control_method_info_om_nom_nom_desktop_file =
{
  {
    -1,
    (gchar *) "OmNomNomDesktopFile",
    (GDBusArgInfo **) &__bamf_dbus_control_method_info_om_nom_nom_desktop_file_IN_ARG_pointers,
    NULL,
    (GDBusAnnotationInfo **) &__bamf_dbus_control_method_om_nom_nom_desktop_file_annotation_info_pointers
  },
  "handle-om-nom-nom-desktop-file",
  FALSE
};

static const GDBusMethodInfo * const __bamf_dbus_control_method_info_pointers[] =
{
  &__bamf_dbus_control_method_info_quit.parent_struct,
  &__bamf_dbus_control_method_info_insert_desktop_file.parent_struct,
  &__bamf_dbus_control_method_info_register_application_for_pid.parent_struct,
  &__bamf_dbus_control_method_info_create_local_desktop_file.parent_struct,
  &__bamf_dbus_control_method_info_om_nom_nom_desktop_file.parent_struct,
  NULL
};

static const _ExtendedGDBusInterfaceInfo __bamf_dbus_control_interface_info =
{
  {
    -1,
    (gchar *) "org.ayatana.bamf.control",
    (GDBusMethodInfo **) &__bamf_dbus_control_method_info_pointers,
    NULL,
    NULL,
    NULL
  },
  "control",
};


/**
 * _bamf_dbus_control_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
_bamf_dbus_control_interface_info (void)
{
  return (GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct;
}

/**
 * _bamf_dbus_control_override_properties:
 * @klass: The class structure for a #GObject derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #BamfDBusControl interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
_bamf_dbus_control_override_properties (GObjectClass *klass G_GNUC_UNUSED, guint property_id_begin)
{
  return property_id_begin - 1;
}


inline static void
_bamf_dbus_control_method_marshal_quit (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_control_method_marshal_insert_desktop_file (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_control_method_marshal_register_application_for_pid (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING_INT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_control_method_marshal_create_local_desktop_file (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_control_method_marshal_om_nom_nom_desktop_file (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}


/**
 * BamfDBusControl:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link>.
 */

/**
 * BamfDBusControlIface:
 * @parent_iface: The parent interface.
 * @handle_create_local_desktop_file: Handler for the #BamfDBusControl::handle-create-local-desktop-file signal.
 * @handle_insert_desktop_file: Handler for the #BamfDBusControl::handle-insert-desktop-file signal.
 * @handle_om_nom_nom_desktop_file: Handler for the #BamfDBusControl::handle-om-nom-nom-desktop-file signal.
 * @handle_quit: Handler for the #BamfDBusControl::handle-quit signal.
 * @handle_register_application_for_pid: Handler for the #BamfDBusControl::handle-register-application-for-pid signal.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link>.
 */

typedef BamfDBusControlIface BamfDBusControlInterface;
G_DEFINE_INTERFACE (BamfDBusControl, _bamf_dbus_control, G_TYPE_OBJECT)

static void
_bamf_dbus_control_default_init (BamfDBusControlIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * BamfDBusControl::handle-quit:
   * @object: A #BamfDBusControl.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-control.Quit">Quit()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_control_complete_quit() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-quit",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusControlIface, handle_quit),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_control_method_marshal_quit,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusControl::handle-insert-desktop-file:
   * @object: A #BamfDBusControl.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_desktop_path: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-control.InsertDesktopFile">InsertDesktopFile()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_control_complete_insert_desktop_file() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-insert-desktop-file",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusControlIface, handle_insert_desktop_file),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_control_method_marshal_insert_desktop_file,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * BamfDBusControl::handle-register-application-for-pid:
   * @object: A #BamfDBusControl.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_application: Argument passed by remote caller.
   * @arg_pid: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-control.RegisterApplicationForPid">RegisterApplicationForPid()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_control_complete_register_application_for_pid() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-register-application-for-pid",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusControlIface, handle_register_application_for_pid),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_control_method_marshal_register_application_for_pid,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_INT);

  /**
   * BamfDBusControl::handle-create-local-desktop-file:
   * @object: A #BamfDBusControl.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_application: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-control.CreateLocalDesktopFile">CreateLocalDesktopFile()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_control_complete_create_local_desktop_file() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-create-local-desktop-file",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusControlIface, handle_create_local_desktop_file),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_control_method_marshal_create_local_desktop_file,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * BamfDBusControl::handle-om-nom-nom-desktop-file:
   * @object: A #BamfDBusControl.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_desktop_path: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-control.OmNomNomDesktopFile">OmNomNomDesktopFile()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_control_complete_om_nom_nom_desktop_file() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   *
   * Deprecated: The D-Bus method has been deprecated.
   */
  g_signal_new ("handle-om-nom-nom-desktop-file",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusControlIface, handle_om_nom_nom_desktop_file),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_control_method_marshal_om_nom_nom_desktop_file,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

}

/**
 * _bamf_dbus_control_call_quit:
 * @proxy: A #BamfDBusControlProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.Quit">Quit()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_call_quit_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_call_quit_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_control_call_quit (
    BamfDBusControl *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Quit",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_control_call_quit_finish:
 * @proxy: A #BamfDBusControlProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_call_quit().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_control_call_quit().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_quit_finish (
    BamfDBusControl *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_quit_sync:
 * @proxy: A #BamfDBusControlProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.Quit">Quit()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_call_quit() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_quit_sync (
    BamfDBusControl *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Quit",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_insert_desktop_file:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_desktop_path: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.InsertDesktopFile">InsertDesktopFile()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_call_insert_desktop_file_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_call_insert_desktop_file_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_control_call_insert_desktop_file (
    BamfDBusControl *proxy,
    const gchar *arg_desktop_path,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "InsertDesktopFile",
    g_variant_new ("(s)",
                   arg_desktop_path),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_control_call_insert_desktop_file_finish:
 * @proxy: A #BamfDBusControlProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_call_insert_desktop_file().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_control_call_insert_desktop_file().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_insert_desktop_file_finish (
    BamfDBusControl *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_insert_desktop_file_sync:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_desktop_path: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.InsertDesktopFile">InsertDesktopFile()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_call_insert_desktop_file() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_insert_desktop_file_sync (
    BamfDBusControl *proxy,
    const gchar *arg_desktop_path,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "InsertDesktopFile",
    g_variant_new ("(s)",
                   arg_desktop_path),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_register_application_for_pid:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_application: Argument to pass with the method invocation.
 * @arg_pid: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.RegisterApplicationForPid">RegisterApplicationForPid()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_call_register_application_for_pid_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_call_register_application_for_pid_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_control_call_register_application_for_pid (
    BamfDBusControl *proxy,
    const gchar *arg_application,
    gint arg_pid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "RegisterApplicationForPid",
    g_variant_new ("(si)",
                   arg_application,
                   arg_pid),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_control_call_register_application_for_pid_finish:
 * @proxy: A #BamfDBusControlProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_call_register_application_for_pid().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_control_call_register_application_for_pid().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_register_application_for_pid_finish (
    BamfDBusControl *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_register_application_for_pid_sync:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_application: Argument to pass with the method invocation.
 * @arg_pid: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.RegisterApplicationForPid">RegisterApplicationForPid()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_call_register_application_for_pid() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_register_application_for_pid_sync (
    BamfDBusControl *proxy,
    const gchar *arg_application,
    gint arg_pid,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "RegisterApplicationForPid",
    g_variant_new ("(si)",
                   arg_application,
                   arg_pid),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_create_local_desktop_file:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_application: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.CreateLocalDesktopFile">CreateLocalDesktopFile()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_call_create_local_desktop_file_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_call_create_local_desktop_file_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_control_call_create_local_desktop_file (
    BamfDBusControl *proxy,
    const gchar *arg_application,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "CreateLocalDesktopFile",
    g_variant_new ("(s)",
                   arg_application),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_control_call_create_local_desktop_file_finish:
 * @proxy: A #BamfDBusControlProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_call_create_local_desktop_file().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_control_call_create_local_desktop_file().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_create_local_desktop_file_finish (
    BamfDBusControl *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_create_local_desktop_file_sync:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_application: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.CreateLocalDesktopFile">CreateLocalDesktopFile()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_call_create_local_desktop_file() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_control_call_create_local_desktop_file_sync (
    BamfDBusControl *proxy,
    const gchar *arg_application,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "CreateLocalDesktopFile",
    g_variant_new ("(s)",
                   arg_application),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_om_nom_nom_desktop_file:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_desktop_path: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.OmNomNomDesktopFile">OmNomNomDesktopFile()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_call_om_nom_nom_desktop_file_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_call_om_nom_nom_desktop_file_sync() for the synchronous, blocking version of this method.
 *
 * Deprecated: The D-Bus method has been deprecated.
 */
void
_bamf_dbus_control_call_om_nom_nom_desktop_file (
    BamfDBusControl *proxy,
    const gchar *arg_desktop_path,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "OmNomNomDesktopFile",
    g_variant_new ("(s)",
                   arg_desktop_path),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_control_call_om_nom_nom_desktop_file_finish:
 * @proxy: A #BamfDBusControlProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_call_om_nom_nom_desktop_file().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_control_call_om_nom_nom_desktop_file().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 *
 * Deprecated: The D-Bus method has been deprecated.
 */
gboolean
_bamf_dbus_control_call_om_nom_nom_desktop_file_finish (
    BamfDBusControl *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_call_om_nom_nom_desktop_file_sync:
 * @proxy: A #BamfDBusControlProxy.
 * @arg_desktop_path: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-control.OmNomNomDesktopFile">OmNomNomDesktopFile()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_call_om_nom_nom_desktop_file() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 *
 * Deprecated: The D-Bus method has been deprecated.
 */
gboolean
_bamf_dbus_control_call_om_nom_nom_desktop_file_sync (
    BamfDBusControl *proxy,
    const gchar *arg_desktop_path,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "OmNomNomDesktopFile",
    g_variant_new ("(s)",
                   arg_desktop_path),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_control_complete_quit:
 * @object: A #BamfDBusControl.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-control.Quit">Quit()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_control_complete_quit (
    BamfDBusControl *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * _bamf_dbus_control_complete_insert_desktop_file:
 * @object: A #BamfDBusControl.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-control.InsertDesktopFile">InsertDesktopFile()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_control_complete_insert_desktop_file (
    BamfDBusControl *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * _bamf_dbus_control_complete_register_application_for_pid:
 * @object: A #BamfDBusControl.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-control.RegisterApplicationForPid">RegisterApplicationForPid()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_control_complete_register_application_for_pid (
    BamfDBusControl *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * _bamf_dbus_control_complete_create_local_desktop_file:
 * @object: A #BamfDBusControl.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-control.CreateLocalDesktopFile">CreateLocalDesktopFile()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_control_complete_create_local_desktop_file (
    BamfDBusControl *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * _bamf_dbus_control_complete_om_nom_nom_desktop_file:
 * @object: A #BamfDBusControl.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-control.OmNomNomDesktopFile">OmNomNomDesktopFile()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 *
 * Deprecated: The D-Bus method has been deprecated.
 */
void
_bamf_dbus_control_complete_om_nom_nom_desktop_file (
    BamfDBusControl *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/* ------------------------------------------------------------------------ */

/**
 * BamfDBusControlProxy:
 *
 * The #BamfDBusControlProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * BamfDBusControlProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #BamfDBusControlProxy.
 */

struct _BamfDBusControlProxyPrivate
{
  GData *qdata;
};

static void _bamf_dbus_control_proxy_iface_init (BamfDBusControlIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (BamfDBusControlProxy, _bamf_dbus_control_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (BamfDBusControlProxy)
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_CONTROL, _bamf_dbus_control_proxy_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (BamfDBusControlProxy, _bamf_dbus_control_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_CONTROL, _bamf_dbus_control_proxy_iface_init))

#endif
static void
_bamf_dbus_control_proxy_finalize (GObject *object)
{
  BamfDBusControlProxy *proxy = BAMF_DBUS_CONTROL_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (_bamf_dbus_control_proxy_parent_class)->finalize (object);
}

static void
_bamf_dbus_control_proxy_get_property (GObject      *object G_GNUC_UNUSED,
  guint         prop_id G_GNUC_UNUSED,
  GValue       *value G_GNUC_UNUSED,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
_bamf_dbus_control_proxy_set_property (GObject      *object G_GNUC_UNUSED,
  guint         prop_id G_GNUC_UNUSED,
  const GValue *value G_GNUC_UNUSED,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
_bamf_dbus_control_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  gsize n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], BAMF_DBUS_TYPE_CONTROL);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, BAMF_DBUS_TYPE_CONTROL);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
_bamf_dbus_control_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  BamfDBusControlProxy *proxy = BAMF_DBUS_CONTROL_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static void
_bamf_dbus_control_proxy_init (BamfDBusControlProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = _bamf_dbus_control_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, BAMF_DBUS_TYPE_CONTROL_PROXY, BamfDBusControlProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), _bamf_dbus_control_interface_info ());
}

static void
_bamf_dbus_control_proxy_class_init (BamfDBusControlProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = _bamf_dbus_control_proxy_finalize;
  gobject_class->get_property = _bamf_dbus_control_proxy_get_property;
  gobject_class->set_property = _bamf_dbus_control_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = _bamf_dbus_control_proxy_g_signal;
  proxy_class->g_properties_changed = _bamf_dbus_control_proxy_g_properties_changed;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (BamfDBusControlProxyPrivate));
#endif
}

static void
_bamf_dbus_control_proxy_iface_init (BamfDBusControlIface *iface G_GNUC_UNUSED)
{
}

/**
 * _bamf_dbus_control_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_proxy_new_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
_bamf_dbus_control_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (BAMF_DBUS_TYPE_CONTROL_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.control", NULL);
}

/**
 * _bamf_dbus_control_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with _bamf_dbus_control_proxy_new().
 *
 * Returns: (transfer full) (type BamfDBusControlProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusControl *
_bamf_dbus_control_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return BAMF_DBUS_CONTROL (ret);
  else
    return NULL;
}

/**
 * _bamf_dbus_control_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type BamfDBusControlProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusControl *
_bamf_dbus_control_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (BAMF_DBUS_TYPE_CONTROL_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.control", NULL);
  if (ret != NULL)
    return BAMF_DBUS_CONTROL (ret);
  else
    return NULL;
}


/**
 * _bamf_dbus_control_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like _bamf_dbus_control_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_control_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See _bamf_dbus_control_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
_bamf_dbus_control_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (BAMF_DBUS_TYPE_CONTROL_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.control", NULL);
}

/**
 * _bamf_dbus_control_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_control_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with _bamf_dbus_control_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type BamfDBusControlProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusControl *
_bamf_dbus_control_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return BAMF_DBUS_CONTROL (ret);
  else
    return NULL;
}

/**
 * _bamf_dbus_control_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like _bamf_dbus_control_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_control_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type BamfDBusControlProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusControl *
_bamf_dbus_control_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (BAMF_DBUS_TYPE_CONTROL_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.control", NULL);
  if (ret != NULL)
    return BAMF_DBUS_CONTROL (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * BamfDBusControlSkeleton:
 *
 * The #BamfDBusControlSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * BamfDBusControlSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #BamfDBusControlSkeleton.
 */

struct _BamfDBusControlSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
__bamf_dbus_control_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  BamfDBusControlSkeleton *skeleton = BAMF_DBUS_CONTROL_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  guint num_extra;
  gsize n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], BAMF_DBUS_TYPE_CONTROL);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, BAMF_DBUS_TYPE_CONTROL);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
__bamf_dbus_control_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  BamfDBusControlSkeleton *skeleton = BAMF_DBUS_CONTROL_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
__bamf_dbus_control_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  BamfDBusControlSkeleton *skeleton = BAMF_DBUS_CONTROL_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_control_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable __bamf_dbus_control_skeleton_vtable =
{
  __bamf_dbus_control_skeleton_handle_method_call,
  __bamf_dbus_control_skeleton_handle_get_property,
  __bamf_dbus_control_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
_bamf_dbus_control_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return _bamf_dbus_control_interface_info ();
}

static GDBusInterfaceVTable *
_bamf_dbus_control_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &__bamf_dbus_control_skeleton_vtable;
}

static GVariant *
_bamf_dbus_control_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  BamfDBusControlSkeleton *skeleton = BAMF_DBUS_CONTROL_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_84
  g_variant_builder_init_static (&builder, G_VARIANT_TYPE ("a{sv}"));
#else
  g_variant_builder_init(&builder, G_VARIANT_TYPE ("a{sv}"));
#endif
  if (__bamf_dbus_control_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; __bamf_dbus_control_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = __bamf_dbus_control_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = __bamf_dbus_control_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.control", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static void
_bamf_dbus_control_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton G_GNUC_UNUSED)
{
}

static void _bamf_dbus_control_skeleton_iface_init (BamfDBusControlIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (BamfDBusControlSkeleton, _bamf_dbus_control_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (BamfDBusControlSkeleton)
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_CONTROL, _bamf_dbus_control_skeleton_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (BamfDBusControlSkeleton, _bamf_dbus_control_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_CONTROL, _bamf_dbus_control_skeleton_iface_init))

#endif
static void
_bamf_dbus_control_skeleton_finalize (GObject *object)
{
  BamfDBusControlSkeleton *skeleton = BAMF_DBUS_CONTROL_SKELETON (object);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  /* coverity[missing_lock : SUPPRESS] */
  g_clear_pointer (&skeleton->priv->changed_properties_idle_source, g_source_destroy);
#else
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
skeleton->priv->changed_properties_idle_source = NULL;
#endif
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (_bamf_dbus_control_skeleton_parent_class)->finalize (object);
}

static void
_bamf_dbus_control_skeleton_init (BamfDBusControlSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = _bamf_dbus_control_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, BAMF_DBUS_TYPE_CONTROL_SKELETON, BamfDBusControlSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
}

static void
_bamf_dbus_control_skeleton_class_init (BamfDBusControlSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = _bamf_dbus_control_skeleton_finalize;

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = _bamf_dbus_control_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = _bamf_dbus_control_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = _bamf_dbus_control_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = _bamf_dbus_control_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (BamfDBusControlSkeletonPrivate));
#endif
}

static void
_bamf_dbus_control_skeleton_iface_init (BamfDBusControlIface *iface G_GNUC_UNUSED)
{
}

/**
 * _bamf_dbus_control_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-control.top_of_page">org.ayatana.bamf.control</link>.
 *
 * Returns: (transfer full) (type BamfDBusControlSkeleton): The skeleton object.
 */
BamfDBusControl *
_bamf_dbus_control_skeleton_new (void)
{
  return BAMF_DBUS_CONTROL (g_object_new (BAMF_DBUS_TYPE_CONTROL_SKELETON, NULL));
}

/* ------------------------------------------------------------------------
 * Code for interface org.ayatana.bamf.matcher
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:BamfDBusMatcher
 * @title: BamfDBusMatcher
 * @short_description: Generated C code for the org.ayatana.bamf.matcher D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link> D-Bus interface in C.
 */

enum
{
  BAMF_DBUS__MATCHER_ACTIVE_APPLICATION_CHANGED,
  BAMF_DBUS__MATCHER_ACTIVE_WINDOW_CHANGED,
  BAMF_DBUS__MATCHER_VIEW_CLOSED,
  BAMF_DBUS__MATCHER_VIEW_OPENED,
  BAMF_DBUS__MATCHER_STACKING_ORDER_CHANGED,
  BAMF_DBUS__MATCHER_RUNNING_APPLICATIONS_CHANGED,
};

static unsigned BAMF_DBUS__MATCHER_SIGNALS[6] = { 0 };

/* ---- Introspection data for org.ayatana.bamf.matcher ---- */

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_xids_for_application_IN_ARG_desktop_file =
{
  {
    -1,
    (gchar *) "desktop_file",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_xids_for_application_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_xids_for_application_IN_ARG_desktop_file.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_xids_for_application_OUT_ARG_xids =
{
  {
    -1,
    (gchar *) "xids",
    (gchar *) "au",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_xids_for_application_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_xids_for_application_OUT_ARG_xids.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_xids_for_application =
{
  {
    -1,
    (gchar *) "XidsForApplication",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_xids_for_application_IN_ARG_pointers,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_xids_for_application_OUT_ARG_pointers,
    NULL
  },
  "handle-xids-for-application",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_tab_paths_OUT_ARG_paths =
{
  {
    -1,
    (gchar *) "paths",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_tab_paths_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_tab_paths_OUT_ARG_paths.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_tab_paths =
{
  {
    -1,
    (gchar *) "TabPaths",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_tab_paths_OUT_ARG_pointers,
    NULL
  },
  "handle-tab-paths",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_running_applications_OUT_ARG_paths =
{
  {
    -1,
    (gchar *) "paths",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_running_applications_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_running_applications_OUT_ARG_paths.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_running_applications =
{
  {
    -1,
    (gchar *) "RunningApplications",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_running_applications_OUT_ARG_pointers,
    NULL
  },
  "handle-running-applications",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_running_applications_desktop_files_OUT_ARG_paths =
{
  {
    -1,
    (gchar *) "paths",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_running_applications_desktop_files_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_running_applications_desktop_files_OUT_ARG_paths.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_running_applications_desktop_files =
{
  {
    -1,
    (gchar *) "RunningApplicationsDesktopFiles",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_running_applications_desktop_files_OUT_ARG_pointers,
    NULL
  },
  "handle-running-applications-desktop-files",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_register_favorites_IN_ARG_favorites =
{
  {
    -1,
    (gchar *) "favorites",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_register_favorites_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_register_favorites_IN_ARG_favorites.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_register_favorites =
{
  {
    -1,
    (gchar *) "RegisterFavorites",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_register_favorites_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-register-favorites",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_path_for_application_IN_ARG_desktop_file =
{
  {
    -1,
    (gchar *) "desktop_file",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_path_for_application_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_path_for_application_IN_ARG_desktop_file.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_path_for_application_OUT_ARG_path =
{
  {
    -1,
    (gchar *) "path",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_path_for_application_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_path_for_application_OUT_ARG_path.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_path_for_application =
{
  {
    -1,
    (gchar *) "PathForApplication",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_path_for_application_IN_ARG_pointers,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_path_for_application_OUT_ARG_pointers,
    NULL
  },
  "handle-path-for-application",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_window_paths_OUT_ARG_paths =
{
  {
    -1,
    (gchar *) "paths",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_window_paths_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_window_paths_OUT_ARG_paths.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_window_paths =
{
  {
    -1,
    (gchar *) "WindowPaths",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_window_paths_OUT_ARG_pointers,
    NULL
  },
  "handle-window-paths",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_application_paths_OUT_ARG_paths =
{
  {
    -1,
    (gchar *) "paths",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_application_paths_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_application_paths_OUT_ARG_paths.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_application_paths =
{
  {
    -1,
    (gchar *) "ApplicationPaths",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_application_paths_OUT_ARG_pointers,
    NULL
  },
  "handle-application-paths",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_application_is_running_IN_ARG_desktop_file =
{
  {
    -1,
    (gchar *) "desktop_file",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_application_is_running_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_application_is_running_IN_ARG_desktop_file.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_application_is_running_OUT_ARG_running =
{
  {
    -1,
    (gchar *) "running",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_application_is_running_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_application_is_running_OUT_ARG_running.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_application_is_running =
{
  {
    -1,
    (gchar *) "ApplicationIsRunning",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_application_is_running_IN_ARG_pointers,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_application_is_running_OUT_ARG_pointers,
    NULL
  },
  "handle-application-is-running",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_application_for_xid_IN_ARG_xid =
{
  {
    -1,
    (gchar *) "xid",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_application_for_xid_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_application_for_xid_IN_ARG_xid.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_application_for_xid_OUT_ARG_application =
{
  {
    -1,
    (gchar *) "application",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_application_for_xid_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_application_for_xid_OUT_ARG_application.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_application_for_xid =
{
  {
    -1,
    (gchar *) "ApplicationForXid",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_application_for_xid_IN_ARG_pointers,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_application_for_xid_OUT_ARG_pointers,
    NULL
  },
  "handle-application-for-xid",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_active_window_OUT_ARG_window =
{
  {
    -1,
    (gchar *) "window",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_active_window_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_active_window_OUT_ARG_window.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_active_window =
{
  {
    -1,
    (gchar *) "ActiveWindow",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_active_window_OUT_ARG_pointers,
    NULL
  },
  "handle-active-window",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_active_application_OUT_ARG_application =
{
  {
    -1,
    (gchar *) "application",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_active_application_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_active_application_OUT_ARG_application.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_active_application =
{
  {
    -1,
    (gchar *) "ActiveApplication",
    NULL,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_active_application_OUT_ARG_pointers,
    NULL
  },
  "handle-active-application",
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_window_stack_for_monitor_IN_ARG_monitor_id =
{
  {
    -1,
    (gchar *) "monitor_id",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_window_stack_for_monitor_IN_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_window_stack_for_monitor_IN_ARG_monitor_id.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_method_info_window_stack_for_monitor_OUT_ARG_window_list =
{
  {
    -1,
    (gchar *) "window_list",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_method_info_window_stack_for_monitor_OUT_ARG_pointers[] =
{
  &__bamf_dbus_matcher_method_info_window_stack_for_monitor_OUT_ARG_window_list.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo __bamf_dbus_matcher_method_info_window_stack_for_monitor =
{
  {
    -1,
    (gchar *) "WindowStackForMonitor",
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_window_stack_for_monitor_IN_ARG_pointers,
    (GDBusArgInfo **) &__bamf_dbus_matcher_method_info_window_stack_for_monitor_OUT_ARG_pointers,
    NULL
  },
  "handle-window-stack-for-monitor",
  FALSE
};

static const GDBusMethodInfo * const __bamf_dbus_matcher_method_info_pointers[] =
{
  &__bamf_dbus_matcher_method_info_xids_for_application.parent_struct,
  &__bamf_dbus_matcher_method_info_tab_paths.parent_struct,
  &__bamf_dbus_matcher_method_info_running_applications.parent_struct,
  &__bamf_dbus_matcher_method_info_running_applications_desktop_files.parent_struct,
  &__bamf_dbus_matcher_method_info_register_favorites.parent_struct,
  &__bamf_dbus_matcher_method_info_path_for_application.parent_struct,
  &__bamf_dbus_matcher_method_info_window_paths.parent_struct,
  &__bamf_dbus_matcher_method_info_application_paths.parent_struct,
  &__bamf_dbus_matcher_method_info_application_is_running.parent_struct,
  &__bamf_dbus_matcher_method_info_application_for_xid.parent_struct,
  &__bamf_dbus_matcher_method_info_active_window.parent_struct,
  &__bamf_dbus_matcher_method_info_active_application.parent_struct,
  &__bamf_dbus_matcher_method_info_window_stack_for_monitor.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_active_application_changed_ARG_old_app =
{
  {
    -1,
    (gchar *) "old_app",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_active_application_changed_ARG_new_app =
{
  {
    -1,
    (gchar *) "new_app",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_signal_info_active_application_changed_ARG_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_active_application_changed_ARG_old_app.parent_struct,
  &__bamf_dbus_matcher_signal_info_active_application_changed_ARG_new_app.parent_struct,
  NULL
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_active_application_changed =
{
  {
    -1,
    (gchar *) "ActiveApplicationChanged",
    (GDBusArgInfo **) &__bamf_dbus_matcher_signal_info_active_application_changed_ARG_pointers,
    NULL
  },
  "active-application-changed"
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_active_window_changed_ARG_old_win =
{
  {
    -1,
    (gchar *) "old_win",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_active_window_changed_ARG_new_win =
{
  {
    -1,
    (gchar *) "new_win",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_signal_info_active_window_changed_ARG_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_active_window_changed_ARG_old_win.parent_struct,
  &__bamf_dbus_matcher_signal_info_active_window_changed_ARG_new_win.parent_struct,
  NULL
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_active_window_changed =
{
  {
    -1,
    (gchar *) "ActiveWindowChanged",
    (GDBusArgInfo **) &__bamf_dbus_matcher_signal_info_active_window_changed_ARG_pointers,
    NULL
  },
  "active-window-changed"
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_view_closed_ARG_path =
{
  {
    -1,
    (gchar *) "path",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_view_closed_ARG_type =
{
  {
    -1,
    (gchar *) "type",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_signal_info_view_closed_ARG_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_view_closed_ARG_path.parent_struct,
  &__bamf_dbus_matcher_signal_info_view_closed_ARG_type.parent_struct,
  NULL
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_view_closed =
{
  {
    -1,
    (gchar *) "ViewClosed",
    (GDBusArgInfo **) &__bamf_dbus_matcher_signal_info_view_closed_ARG_pointers,
    NULL
  },
  "view-closed"
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_view_opened_ARG_path =
{
  {
    -1,
    (gchar *) "path",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_view_opened_ARG_type =
{
  {
    -1,
    (gchar *) "type",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_signal_info_view_opened_ARG_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_view_opened_ARG_path.parent_struct,
  &__bamf_dbus_matcher_signal_info_view_opened_ARG_type.parent_struct,
  NULL
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_view_opened =
{
  {
    -1,
    (gchar *) "ViewOpened",
    (GDBusArgInfo **) &__bamf_dbus_matcher_signal_info_view_opened_ARG_pointers,
    NULL
  },
  "view-opened"
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_stacking_order_changed =
{
  {
    -1,
    (gchar *) "StackingOrderChanged",
    NULL,
    NULL
  },
  "stacking-order-changed"
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_running_applications_changed_ARG_opened_desktop_files =
{
  {
    -1,
    (gchar *) "opened_desktop_files",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo __bamf_dbus_matcher_signal_info_running_applications_changed_ARG_closed_desktop_files =
{
  {
    -1,
    (gchar *) "closed_desktop_files",
    (gchar *) "as",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const __bamf_dbus_matcher_signal_info_running_applications_changed_ARG_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_running_applications_changed_ARG_opened_desktop_files.parent_struct,
  &__bamf_dbus_matcher_signal_info_running_applications_changed_ARG_closed_desktop_files.parent_struct,
  NULL
};

static const _ExtendedGDBusSignalInfo __bamf_dbus_matcher_signal_info_running_applications_changed =
{
  {
    -1,
    (gchar *) "RunningApplicationsChanged",
    (GDBusArgInfo **) &__bamf_dbus_matcher_signal_info_running_applications_changed_ARG_pointers,
    NULL
  },
  "running-applications-changed"
};

static const GDBusSignalInfo * const __bamf_dbus_matcher_signal_info_pointers[] =
{
  &__bamf_dbus_matcher_signal_info_active_application_changed.parent_struct,
  &__bamf_dbus_matcher_signal_info_active_window_changed.parent_struct,
  &__bamf_dbus_matcher_signal_info_view_closed.parent_struct,
  &__bamf_dbus_matcher_signal_info_view_opened.parent_struct,
  &__bamf_dbus_matcher_signal_info_stacking_order_changed.parent_struct,
  &__bamf_dbus_matcher_signal_info_running_applications_changed.parent_struct,
  NULL
};

static const _ExtendedGDBusInterfaceInfo __bamf_dbus_matcher_interface_info =
{
  {
    -1,
    (gchar *) "org.ayatana.bamf.matcher",
    (GDBusMethodInfo **) &__bamf_dbus_matcher_method_info_pointers,
    (GDBusSignalInfo **) &__bamf_dbus_matcher_signal_info_pointers,
    NULL,
    NULL
  },
  "matcher",
};


/**
 * _bamf_dbus_matcher_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
_bamf_dbus_matcher_interface_info (void)
{
  return (GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct;
}

/**
 * _bamf_dbus_matcher_override_properties:
 * @klass: The class structure for a #GObject derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #BamfDBusMatcher interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
_bamf_dbus_matcher_override_properties (GObjectClass *klass G_GNUC_UNUSED, guint property_id_begin)
{
  return property_id_begin - 1;
}


inline static void
_bamf_dbus_matcher_signal_marshal_active_application_changed (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_VOID__STRING_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_signal_marshal_active_window_changed (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_VOID__STRING_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_signal_marshal_view_closed (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_VOID__STRING_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_signal_marshal_view_opened (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_VOID__STRING_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_signal_marshal_stacking_order_changed (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  g_cclosure_marshal_VOID__VOID (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_signal_marshal_running_applications_changed (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_VOID__BOXED_BOXED (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_xids_for_application (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_tab_paths (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_running_applications (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_running_applications_desktop_files (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_register_favorites (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_BOXED (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_path_for_application (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_window_paths (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_application_paths (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_application_is_running (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_application_for_xid (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_UINT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_active_window (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_active_application (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
_bamf_dbus_matcher_method_marshal_window_stack_for_monitor (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_INT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}


/**
 * BamfDBusMatcher:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link>.
 */

/**
 * BamfDBusMatcherIface:
 * @parent_iface: The parent interface.
 * @handle_active_application: Handler for the #BamfDBusMatcher::handle-active-application signal.
 * @handle_active_window: Handler for the #BamfDBusMatcher::handle-active-window signal.
 * @handle_application_for_xid: Handler for the #BamfDBusMatcher::handle-application-for-xid signal.
 * @handle_application_is_running: Handler for the #BamfDBusMatcher::handle-application-is-running signal.
 * @handle_application_paths: Handler for the #BamfDBusMatcher::handle-application-paths signal.
 * @handle_path_for_application: Handler for the #BamfDBusMatcher::handle-path-for-application signal.
 * @handle_register_favorites: Handler for the #BamfDBusMatcher::handle-register-favorites signal.
 * @handle_running_applications: Handler for the #BamfDBusMatcher::handle-running-applications signal.
 * @handle_running_applications_desktop_files: Handler for the #BamfDBusMatcher::handle-running-applications-desktop-files signal.
 * @handle_tab_paths: Handler for the #BamfDBusMatcher::handle-tab-paths signal.
 * @handle_window_paths: Handler for the #BamfDBusMatcher::handle-window-paths signal.
 * @handle_window_stack_for_monitor: Handler for the #BamfDBusMatcher::handle-window-stack-for-monitor signal.
 * @handle_xids_for_application: Handler for the #BamfDBusMatcher::handle-xids-for-application signal.
 * @active_application_changed: Handler for the #BamfDBusMatcher::active-application-changed signal.
 * @active_window_changed: Handler for the #BamfDBusMatcher::active-window-changed signal.
 * @running_applications_changed: Handler for the #BamfDBusMatcher::running-applications-changed signal.
 * @stacking_order_changed: Handler for the #BamfDBusMatcher::stacking-order-changed signal.
 * @view_closed: Handler for the #BamfDBusMatcher::view-closed signal.
 * @view_opened: Handler for the #BamfDBusMatcher::view-opened signal.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link>.
 */

typedef BamfDBusMatcherIface BamfDBusMatcherInterface;
G_DEFINE_INTERFACE (BamfDBusMatcher, _bamf_dbus_matcher, G_TYPE_OBJECT)

static void
_bamf_dbus_matcher_default_init (BamfDBusMatcherIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * BamfDBusMatcher::handle-xids-for-application:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_desktop_file: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.XidsForApplication">XidsForApplication()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_xids_for_application() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-xids-for-application",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_xids_for_application),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_xids_for_application,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::handle-tab-paths:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.TabPaths">TabPaths()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_tab_paths() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-tab-paths",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_tab_paths),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_tab_paths,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-running-applications:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplications">RunningApplications()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_running_applications() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-running-applications",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_running_applications),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_running_applications,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-running-applications-desktop-files:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplicationsDesktopFiles">RunningApplicationsDesktopFiles()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_running_applications_desktop_files() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-running-applications-desktop-files",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_running_applications_desktop_files),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_running_applications_desktop_files,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-register-favorites:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_favorites: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RegisterFavorites">RegisterFavorites()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_register_favorites() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-register-favorites",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_register_favorites),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_register_favorites,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRV);

  /**
   * BamfDBusMatcher::handle-path-for-application:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_desktop_file: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.PathForApplication">PathForApplication()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_path_for_application() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-path-for-application",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_path_for_application),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_path_for_application,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::handle-window-paths:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowPaths">WindowPaths()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_window_paths() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-window-paths",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_window_paths),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_window_paths,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-application-paths:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationPaths">ApplicationPaths()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_application_paths() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-application-paths",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_application_paths),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_application_paths,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-application-is-running:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_desktop_file: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationIsRunning">ApplicationIsRunning()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_application_is_running() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-application-is-running",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_application_is_running),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_application_is_running,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::handle-application-for-xid:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_xid: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationForXid">ApplicationForXid()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_application_for_xid() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-application-for-xid",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_application_for_xid),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_application_for_xid,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT);

  /**
   * BamfDBusMatcher::handle-active-window:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveWindow">ActiveWindow()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_active_window() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-active-window",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_active_window),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_active_window,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-active-application:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveApplication">ActiveApplication()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_active_application() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-active-application",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_active_application),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_active_application,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * BamfDBusMatcher::handle-window-stack-for-monitor:
   * @object: A #BamfDBusMatcher.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_monitor_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowStackForMonitor">WindowStackForMonitor()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call _bamf_dbus_matcher_complete_window_stack_for_monitor() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-window-stack-for-monitor",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (BamfDBusMatcherIface, handle_window_stack_for_monitor),
    g_signal_accumulator_true_handled,
    NULL,
      _bamf_dbus_matcher_method_marshal_window_stack_for_monitor,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_INT);

  /* GObject signals for received D-Bus signals: */
  /**
   * BamfDBusMatcher::active-application-changed:
   * @object: A #BamfDBusMatcher.
   * @arg_old_app: Argument.
   * @arg_new_app: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ActiveApplicationChanged">"ActiveApplicationChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_ACTIVE_APPLICATION_CHANGED] =
    g_signal_new ("active-application-changed",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, active_application_changed),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_active_application_changed,
      G_TYPE_NONE,
      2, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::active-window-changed:
   * @object: A #BamfDBusMatcher.
   * @arg_old_win: Argument.
   * @arg_new_win: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ActiveWindowChanged">"ActiveWindowChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_ACTIVE_WINDOW_CHANGED] =
    g_signal_new ("active-window-changed",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, active_window_changed),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_active_window_changed,
      G_TYPE_NONE,
      2, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::view-closed:
   * @object: A #BamfDBusMatcher.
   * @arg_path: Argument.
   * @arg_type: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ViewClosed">"ViewClosed"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_VIEW_CLOSED] =
    g_signal_new ("view-closed",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, view_closed),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_view_closed,
      G_TYPE_NONE,
      2, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::view-opened:
   * @object: A #BamfDBusMatcher.
   * @arg_path: Argument.
   * @arg_type: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ViewOpened">"ViewOpened"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_VIEW_OPENED] =
    g_signal_new ("view-opened",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, view_opened),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_view_opened,
      G_TYPE_NONE,
      2, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * BamfDBusMatcher::stacking-order-changed:
   * @object: A #BamfDBusMatcher.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.StackingOrderChanged">"StackingOrderChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_STACKING_ORDER_CHANGED] =
    g_signal_new ("stacking-order-changed",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, stacking_order_changed),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_stacking_order_changed,
      G_TYPE_NONE,
      0);

  /**
   * BamfDBusMatcher::running-applications-changed:
   * @object: A #BamfDBusMatcher.
   * @arg_opened_desktop_files: Argument.
   * @arg_closed_desktop_files: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-ayatana-bamf-matcher.RunningApplicationsChanged">"RunningApplicationsChanged"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_RUNNING_APPLICATIONS_CHANGED] =
    g_signal_new ("running-applications-changed",
      G_TYPE_FROM_INTERFACE (iface),
      G_SIGNAL_RUN_LAST,
      G_STRUCT_OFFSET (BamfDBusMatcherIface, running_applications_changed),
      NULL,
      NULL,
      _bamf_dbus_matcher_signal_marshal_running_applications_changed,
      G_TYPE_NONE,
      2, G_TYPE_STRV, G_TYPE_STRV);

}

/**
 * _bamf_dbus_matcher_emit_active_application_changed:
 * @object: A #BamfDBusMatcher.
 * @arg_old_app: Argument to pass with the signal.
 * @arg_new_app: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ActiveApplicationChanged">"ActiveApplicationChanged"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_active_application_changed (
    BamfDBusMatcher *object,
    const gchar *arg_old_app,
    const gchar *arg_new_app)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_ACTIVE_APPLICATION_CHANGED], 0, arg_old_app, arg_new_app);
}

/**
 * _bamf_dbus_matcher_emit_active_window_changed:
 * @object: A #BamfDBusMatcher.
 * @arg_old_win: Argument to pass with the signal.
 * @arg_new_win: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ActiveWindowChanged">"ActiveWindowChanged"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_active_window_changed (
    BamfDBusMatcher *object,
    const gchar *arg_old_win,
    const gchar *arg_new_win)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_ACTIVE_WINDOW_CHANGED], 0, arg_old_win, arg_new_win);
}

/**
 * _bamf_dbus_matcher_emit_view_closed:
 * @object: A #BamfDBusMatcher.
 * @arg_path: Argument to pass with the signal.
 * @arg_type: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ViewClosed">"ViewClosed"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_view_closed (
    BamfDBusMatcher *object,
    const gchar *arg_path,
    const gchar *arg_type)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_VIEW_CLOSED], 0, arg_path, arg_type);
}

/**
 * _bamf_dbus_matcher_emit_view_opened:
 * @object: A #BamfDBusMatcher.
 * @arg_path: Argument to pass with the signal.
 * @arg_type: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.ViewOpened">"ViewOpened"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_view_opened (
    BamfDBusMatcher *object,
    const gchar *arg_path,
    const gchar *arg_type)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_VIEW_OPENED], 0, arg_path, arg_type);
}

/**
 * _bamf_dbus_matcher_emit_stacking_order_changed:
 * @object: A #BamfDBusMatcher.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.StackingOrderChanged">"StackingOrderChanged"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_stacking_order_changed (
    BamfDBusMatcher *object)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_STACKING_ORDER_CHANGED], 0);
}

/**
 * _bamf_dbus_matcher_emit_running_applications_changed:
 * @object: A #BamfDBusMatcher.
 * @arg_opened_desktop_files: Argument to pass with the signal.
 * @arg_closed_desktop_files: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-ayatana-bamf-matcher.RunningApplicationsChanged">"RunningApplicationsChanged"</link> D-Bus signal.
 */
void
_bamf_dbus_matcher_emit_running_applications_changed (
    BamfDBusMatcher *object,
    const gchar *const *arg_opened_desktop_files,
    const gchar *const *arg_closed_desktop_files)
{
  g_signal_emit (object, BAMF_DBUS__MATCHER_SIGNALS[BAMF_DBUS__MATCHER_RUNNING_APPLICATIONS_CHANGED], 0, arg_opened_desktop_files, arg_closed_desktop_files);
}

/**
 * _bamf_dbus_matcher_call_xids_for_application:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.XidsForApplication">XidsForApplication()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_xids_for_application_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_xids_for_application_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_xids_for_application (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "XidsForApplication",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_xids_for_application_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_xids: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_xids_for_application().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_xids_for_application().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_xids_for_application_finish (
    BamfDBusMatcher *proxy,
    GVariant ** out_xids,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@au)",
                 out_xids);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_xids_for_application_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @out_xids: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.XidsForApplication">XidsForApplication()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_xids_for_application() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_xids_for_application_sync (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    GVariant ** out_xids,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "XidsForApplication",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@au)",
                 out_xids);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_tab_paths:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.TabPaths">TabPaths()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_tab_paths_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_tab_paths_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_tab_paths (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "TabPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_tab_paths_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_tab_paths().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_tab_paths().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_tab_paths_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_tab_paths_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.TabPaths">TabPaths()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_tab_paths() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_tab_paths_sync (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "TabPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_running_applications:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplications">RunningApplications()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_running_applications_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_running_applications_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_running_applications (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "RunningApplications",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_running_applications_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_running_applications().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_running_applications().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_running_applications_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_running_applications_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplications">RunningApplications()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_running_applications() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_running_applications_sync (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "RunningApplications",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_running_applications_desktop_files:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplicationsDesktopFiles">RunningApplicationsDesktopFiles()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_running_applications_desktop_files_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_running_applications_desktop_files_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_running_applications_desktop_files (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "RunningApplicationsDesktopFiles",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_running_applications_desktop_files_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_running_applications_desktop_files().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_running_applications_desktop_files().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_running_applications_desktop_files_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_running_applications_desktop_files_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplicationsDesktopFiles">RunningApplicationsDesktopFiles()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_running_applications_desktop_files() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_running_applications_desktop_files_sync (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "RunningApplicationsDesktopFiles",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_register_favorites:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_favorites: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RegisterFavorites">RegisterFavorites()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_register_favorites_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_register_favorites_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_register_favorites (
    BamfDBusMatcher *proxy,
    const gchar *const *arg_favorites,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "RegisterFavorites",
    g_variant_new ("(^as)",
                   arg_favorites),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_register_favorites_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_register_favorites().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_register_favorites().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_register_favorites_finish (
    BamfDBusMatcher *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_register_favorites_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_favorites: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RegisterFavorites">RegisterFavorites()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_register_favorites() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_register_favorites_sync (
    BamfDBusMatcher *proxy,
    const gchar *const *arg_favorites,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "RegisterFavorites",
    g_variant_new ("(^as)",
                   arg_favorites),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_path_for_application:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.PathForApplication">PathForApplication()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_path_for_application_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_path_for_application_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_path_for_application (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "PathForApplication",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_path_for_application_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_path: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_path_for_application().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_path_for_application().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_path_for_application_finish (
    BamfDBusMatcher *proxy,
    gchar ** out_path,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_path);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_path_for_application_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @out_path: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.PathForApplication">PathForApplication()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_path_for_application() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_path_for_application_sync (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    gchar ** out_path,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "PathForApplication",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_path);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_window_paths:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowPaths">WindowPaths()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_window_paths_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_window_paths_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_window_paths (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "WindowPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_window_paths_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_window_paths().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_window_paths().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_window_paths_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_window_paths_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowPaths">WindowPaths()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_window_paths() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_window_paths_sync (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "WindowPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_paths:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationPaths">ApplicationPaths()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_application_paths_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_application_paths_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_application_paths (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ApplicationPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_application_paths_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_application_paths().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_application_paths().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_paths_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_paths_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_paths: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationPaths">ApplicationPaths()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_application_paths() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_paths_sync (
    BamfDBusMatcher *proxy,
    gchar *** out_paths,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ApplicationPaths",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_paths);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_is_running:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationIsRunning">ApplicationIsRunning()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_application_is_running_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_application_is_running_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_application_is_running (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ApplicationIsRunning",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_application_is_running_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_running: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_application_is_running().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_application_is_running().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_is_running_finish (
    BamfDBusMatcher *proxy,
    gboolean* out_running,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_running);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_is_running_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_desktop_file: Argument to pass with the method invocation.
 * @out_running: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationIsRunning">ApplicationIsRunning()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_application_is_running() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_is_running_sync (
    BamfDBusMatcher *proxy,
    const gchar *arg_desktop_file,
    gboolean* out_running,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ApplicationIsRunning",
    g_variant_new ("(s)",
                   arg_desktop_file),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_running);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_for_xid:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_xid: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationForXid">ApplicationForXid()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_application_for_xid_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_application_for_xid_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_application_for_xid (
    BamfDBusMatcher *proxy,
    guint arg_xid,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ApplicationForXid",
    g_variant_new ("(u)",
                   arg_xid),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_application_for_xid_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_application: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_application_for_xid().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_application_for_xid().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_for_xid_finish (
    BamfDBusMatcher *proxy,
    gchar ** out_application,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_application);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_application_for_xid_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_xid: Argument to pass with the method invocation.
 * @out_application: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationForXid">ApplicationForXid()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_application_for_xid() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_application_for_xid_sync (
    BamfDBusMatcher *proxy,
    guint arg_xid,
    gchar ** out_application,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ApplicationForXid",
    g_variant_new ("(u)",
                   arg_xid),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_application);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_active_window:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveWindow">ActiveWindow()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_active_window_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_active_window_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_active_window (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ActiveWindow",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_active_window_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_window: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_active_window().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_active_window().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_active_window_finish (
    BamfDBusMatcher *proxy,
    gchar ** out_window,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_window);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_active_window_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_window: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveWindow">ActiveWindow()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_active_window() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_active_window_sync (
    BamfDBusMatcher *proxy,
    gchar ** out_window,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ActiveWindow",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_window);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_active_application:
 * @proxy: A #BamfDBusMatcherProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveApplication">ActiveApplication()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_active_application_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_active_application_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_active_application (
    BamfDBusMatcher *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "ActiveApplication",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_active_application_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_application: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_active_application().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_active_application().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_active_application_finish (
    BamfDBusMatcher *proxy,
    gchar ** out_application,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_application);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_active_application_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_application: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveApplication">ActiveApplication()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_active_application() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_active_application_sync (
    BamfDBusMatcher *proxy,
    gchar ** out_application,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "ActiveApplication",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_application);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_window_stack_for_monitor:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_monitor_id: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowStackForMonitor">WindowStackForMonitor()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_call_window_stack_for_monitor_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_call_window_stack_for_monitor_sync() for the synchronous, blocking version of this method.
 */
void
_bamf_dbus_matcher_call_window_stack_for_monitor (
    BamfDBusMatcher *proxy,
    gint arg_monitor_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "WindowStackForMonitor",
    g_variant_new ("(i)",
                   arg_monitor_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * _bamf_dbus_matcher_call_window_stack_for_monitor_finish:
 * @proxy: A #BamfDBusMatcherProxy.
 * @out_window_list: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_call_window_stack_for_monitor().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with _bamf_dbus_matcher_call_window_stack_for_monitor().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_window_stack_for_monitor_finish (
    BamfDBusMatcher *proxy,
    gchar *** out_window_list,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_window_list);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_call_window_stack_for_monitor_sync:
 * @proxy: A #BamfDBusMatcherProxy.
 * @arg_monitor_id: Argument to pass with the method invocation.
 * @out_window_list: (out) (optional) (array zero-terminated=1): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowStackForMonitor">WindowStackForMonitor()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_call_window_stack_for_monitor() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
_bamf_dbus_matcher_call_window_stack_for_monitor_sync (
    BamfDBusMatcher *proxy,
    gint arg_monitor_id,
    gchar *** out_window_list,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "WindowStackForMonitor",
    g_variant_new ("(i)",
                   arg_monitor_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^as)",
                 out_window_list);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * _bamf_dbus_matcher_complete_xids_for_application:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @xids: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.XidsForApplication">XidsForApplication()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_xids_for_application (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    GVariant *xids)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(@au)",
                   xids));
}

/**
 * _bamf_dbus_matcher_complete_tab_paths:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @paths: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.TabPaths">TabPaths()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_tab_paths (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *paths)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   paths));
}

/**
 * _bamf_dbus_matcher_complete_running_applications:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @paths: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplications">RunningApplications()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_running_applications (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *paths)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   paths));
}

/**
 * _bamf_dbus_matcher_complete_running_applications_desktop_files:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @paths: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RunningApplicationsDesktopFiles">RunningApplicationsDesktopFiles()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_running_applications_desktop_files (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *paths)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   paths));
}

/**
 * _bamf_dbus_matcher_complete_register_favorites:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.RegisterFavorites">RegisterFavorites()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_register_favorites (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * _bamf_dbus_matcher_complete_path_for_application:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @path: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.PathForApplication">PathForApplication()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_path_for_application (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *path)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(s)",
                   path));
}

/**
 * _bamf_dbus_matcher_complete_window_paths:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @paths: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowPaths">WindowPaths()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_window_paths (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *paths)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   paths));
}

/**
 * _bamf_dbus_matcher_complete_application_paths:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @paths: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationPaths">ApplicationPaths()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_application_paths (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *paths)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   paths));
}

/**
 * _bamf_dbus_matcher_complete_application_is_running:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @running: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationIsRunning">ApplicationIsRunning()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_application_is_running (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    gboolean running)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   running));
}

/**
 * _bamf_dbus_matcher_complete_application_for_xid:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @application: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ApplicationForXid">ApplicationForXid()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_application_for_xid (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *application)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(s)",
                   application));
}

/**
 * _bamf_dbus_matcher_complete_active_window:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @window: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveWindow">ActiveWindow()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_active_window (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *window)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(s)",
                   window));
}

/**
 * _bamf_dbus_matcher_complete_active_application:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @application: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.ActiveApplication">ActiveApplication()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_active_application (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *application)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(s)",
                   application));
}

/**
 * _bamf_dbus_matcher_complete_window_stack_for_monitor:
 * @object: A #BamfDBusMatcher.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @window_list: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-ayatana-bamf-matcher.WindowStackForMonitor">WindowStackForMonitor()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
_bamf_dbus_matcher_complete_window_stack_for_monitor (
    BamfDBusMatcher *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    const gchar *const *window_list)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^as)",
                   window_list));
}

/* ------------------------------------------------------------------------ */

/**
 * BamfDBusMatcherProxy:
 *
 * The #BamfDBusMatcherProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * BamfDBusMatcherProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #BamfDBusMatcherProxy.
 */

struct _BamfDBusMatcherProxyPrivate
{
  GData *qdata;
};

static void _bamf_dbus_matcher_proxy_iface_init (BamfDBusMatcherIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (BamfDBusMatcherProxy, _bamf_dbus_matcher_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (BamfDBusMatcherProxy)
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_MATCHER, _bamf_dbus_matcher_proxy_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (BamfDBusMatcherProxy, _bamf_dbus_matcher_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_MATCHER, _bamf_dbus_matcher_proxy_iface_init))

#endif
static void
_bamf_dbus_matcher_proxy_finalize (GObject *object)
{
  BamfDBusMatcherProxy *proxy = BAMF_DBUS_MATCHER_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (_bamf_dbus_matcher_proxy_parent_class)->finalize (object);
}

static void
_bamf_dbus_matcher_proxy_get_property (GObject      *object G_GNUC_UNUSED,
  guint         prop_id G_GNUC_UNUSED,
  GValue       *value G_GNUC_UNUSED,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
_bamf_dbus_matcher_proxy_set_property (GObject      *object G_GNUC_UNUSED,
  guint         prop_id G_GNUC_UNUSED,
  const GValue *value G_GNUC_UNUSED,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
}

static void
_bamf_dbus_matcher_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  gsize n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], BAMF_DBUS_TYPE_MATCHER);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, BAMF_DBUS_TYPE_MATCHER);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
_bamf_dbus_matcher_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  BamfDBusMatcherProxy *proxy = BAMF_DBUS_MATCHER_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static void
_bamf_dbus_matcher_proxy_init (BamfDBusMatcherProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = _bamf_dbus_matcher_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, BAMF_DBUS_TYPE_MATCHER_PROXY, BamfDBusMatcherProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), _bamf_dbus_matcher_interface_info ());
}

static void
_bamf_dbus_matcher_proxy_class_init (BamfDBusMatcherProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = _bamf_dbus_matcher_proxy_finalize;
  gobject_class->get_property = _bamf_dbus_matcher_proxy_get_property;
  gobject_class->set_property = _bamf_dbus_matcher_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = _bamf_dbus_matcher_proxy_g_signal;
  proxy_class->g_properties_changed = _bamf_dbus_matcher_proxy_g_properties_changed;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (BamfDBusMatcherProxyPrivate));
#endif
}

static void
_bamf_dbus_matcher_proxy_iface_init (BamfDBusMatcherIface *iface G_GNUC_UNUSED)
{
}

/**
 * _bamf_dbus_matcher_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_proxy_new_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
_bamf_dbus_matcher_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (BAMF_DBUS_TYPE_MATCHER_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.matcher", NULL);
}

/**
 * _bamf_dbus_matcher_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with _bamf_dbus_matcher_proxy_new().
 *
 * Returns: (transfer full) (type BamfDBusMatcherProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusMatcher *
_bamf_dbus_matcher_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return BAMF_DBUS_MATCHER (ret);
  else
    return NULL;
}

/**
 * _bamf_dbus_matcher_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type BamfDBusMatcherProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusMatcher *
_bamf_dbus_matcher_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (BAMF_DBUS_TYPE_MATCHER_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.matcher", NULL);
  if (ret != NULL)
    return BAMF_DBUS_MATCHER (ret);
  else
    return NULL;
}


/**
 * _bamf_dbus_matcher_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like _bamf_dbus_matcher_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call _bamf_dbus_matcher_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See _bamf_dbus_matcher_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
_bamf_dbus_matcher_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (BAMF_DBUS_TYPE_MATCHER_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.matcher", NULL);
}

/**
 * _bamf_dbus_matcher_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to _bamf_dbus_matcher_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with _bamf_dbus_matcher_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type BamfDBusMatcherProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusMatcher *
_bamf_dbus_matcher_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return BAMF_DBUS_MATCHER (ret);
  else
    return NULL;
}

/**
 * _bamf_dbus_matcher_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like _bamf_dbus_matcher_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See _bamf_dbus_matcher_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type BamfDBusMatcherProxy): The constructed proxy object or %NULL if @error is set.
 */
BamfDBusMatcher *
_bamf_dbus_matcher_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (BAMF_DBUS_TYPE_MATCHER_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.ayatana.bamf.matcher", NULL);
  if (ret != NULL)
    return BAMF_DBUS_MATCHER (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * BamfDBusMatcherSkeleton:
 *
 * The #BamfDBusMatcherSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * BamfDBusMatcherSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #BamfDBusMatcherSkeleton.
 */

struct _BamfDBusMatcherSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
__bamf_dbus_matcher_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  guint num_extra;
  gsize n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], BAMF_DBUS_TYPE_MATCHER);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, BAMF_DBUS_TYPE_MATCHER);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
__bamf_dbus_matcher_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
__bamf_dbus_matcher_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &__bamf_dbus_matcher_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable __bamf_dbus_matcher_skeleton_vtable =
{
  __bamf_dbus_matcher_skeleton_handle_method_call,
  __bamf_dbus_matcher_skeleton_handle_get_property,
  __bamf_dbus_matcher_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
_bamf_dbus_matcher_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return _bamf_dbus_matcher_interface_info ();
}

static GDBusInterfaceVTable *
_bamf_dbus_matcher_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &__bamf_dbus_matcher_skeleton_vtable;
}

static GVariant *
_bamf_dbus_matcher_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_84
  g_variant_builder_init_static (&builder, G_VARIANT_TYPE ("a{sv}"));
#else
  g_variant_builder_init(&builder, G_VARIANT_TYPE ("a{sv}"));
#endif
  if (__bamf_dbus_matcher_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; __bamf_dbus_matcher_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = __bamf_dbus_matcher_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = __bamf_dbus_matcher_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static void
_bamf_dbus_matcher_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton G_GNUC_UNUSED)
{
}

static void
__bamf_dbus_matcher_on_signal_active_application_changed (
    BamfDBusMatcher *object,
    const gchar *arg_old_app,
    const gchar *arg_new_app)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss)",
                   arg_old_app,
                   arg_new_app));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "ActiveApplicationChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
__bamf_dbus_matcher_on_signal_active_window_changed (
    BamfDBusMatcher *object,
    const gchar *arg_old_win,
    const gchar *arg_new_win)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss)",
                   arg_old_win,
                   arg_new_win));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "ActiveWindowChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
__bamf_dbus_matcher_on_signal_view_closed (
    BamfDBusMatcher *object,
    const gchar *arg_path,
    const gchar *arg_type)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss)",
                   arg_path,
                   arg_type));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "ViewClosed",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
__bamf_dbus_matcher_on_signal_view_opened (
    BamfDBusMatcher *object,
    const gchar *arg_path,
    const gchar *arg_type)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(ss)",
                   arg_path,
                   arg_type));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "ViewOpened",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
__bamf_dbus_matcher_on_signal_stacking_order_changed (
    BamfDBusMatcher *object)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("()"));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "StackingOrderChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
__bamf_dbus_matcher_on_signal_running_applications_changed (
    BamfDBusMatcher *object,
    const gchar *const *arg_opened_desktop_files,
    const gchar *const *arg_closed_desktop_files)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(^as^as)",
                   arg_opened_desktop_files,
                   arg_closed_desktop_files));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.ayatana.bamf.matcher", "RunningApplicationsChanged",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void _bamf_dbus_matcher_skeleton_iface_init (BamfDBusMatcherIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (BamfDBusMatcherSkeleton, _bamf_dbus_matcher_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (BamfDBusMatcherSkeleton)
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_MATCHER, _bamf_dbus_matcher_skeleton_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (BamfDBusMatcherSkeleton, _bamf_dbus_matcher_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (BAMF_DBUS_TYPE_MATCHER, _bamf_dbus_matcher_skeleton_iface_init))

#endif
static void
_bamf_dbus_matcher_skeleton_finalize (GObject *object)
{
  BamfDBusMatcherSkeleton *skeleton = BAMF_DBUS_MATCHER_SKELETON (object);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  /* coverity[missing_lock : SUPPRESS] */
  g_clear_pointer (&skeleton->priv->changed_properties_idle_source, g_source_destroy);
#else
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
skeleton->priv->changed_properties_idle_source = NULL;
#endif
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (_bamf_dbus_matcher_skeleton_parent_class)->finalize (object);
}

static void
_bamf_dbus_matcher_skeleton_init (BamfDBusMatcherSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = _bamf_dbus_matcher_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, BAMF_DBUS_TYPE_MATCHER_SKELETON, BamfDBusMatcherSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
}

static void
_bamf_dbus_matcher_skeleton_class_init (BamfDBusMatcherSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = _bamf_dbus_matcher_skeleton_finalize;

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = _bamf_dbus_matcher_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = _bamf_dbus_matcher_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = _bamf_dbus_matcher_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = _bamf_dbus_matcher_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (BamfDBusMatcherSkeletonPrivate));
#endif
}

static void
_bamf_dbus_matcher_skeleton_iface_init (BamfDBusMatcherIface *iface)
{
  iface->active_application_changed = __bamf_dbus_matcher_on_signal_active_application_changed;
  iface->active_window_changed = __bamf_dbus_matcher_on_signal_active_window_changed;
  iface->view_closed = __bamf_dbus_matcher_on_signal_view_closed;
  iface->view_opened = __bamf_dbus_matcher_on_signal_view_opened;
  iface->stacking_order_changed = __bamf_dbus_matcher_on_signal_stacking_order_changed;
  iface->running_applications_changed = __bamf_dbus_matcher_on_signal_running_applications_changed;
}

/**
 * _bamf_dbus_matcher_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-ayatana-bamf-matcher.top_of_page">org.ayatana.bamf.matcher</link>.
 *
 * Returns: (transfer full) (type BamfDBusMatcherSkeleton): The skeleton object.
 */
BamfDBusMatcher *
_bamf_dbus_matcher_skeleton_new (void)
{
  return BAMF_DBUS_MATCHER (g_object_new (BAMF_DBUS_TYPE_MATCHER_SKELETON, NULL));
}

